{% if filetype_loop == 0 %}ID,Friendly Name,Serial Number Decimal Format,Issued To,Issued By,Valid From,Expiration Date,Used By,Key Size,Group Tag,Self Signed,Signature Algorithm,Portals Using The Tag,SHA 256 Fingerprint
{%- for cert in certs %}
{%-     for item in cert %}
{{ item.id }},{{ item.friendlyName | replace (","," ")}},{{ item.serialNumberDecimalFormat }},{{ item.issuedTo }},{{ item.issuedBy }},{{ item.validFrom }},{{ item.expirationDate }},{{ item.usedBy }},{{ item.keySize }},{{ item.groupTag }},{{ item.selfSigned }},{{ item.signatureAlgorithm }},{{ item.portalsUsingTheTag }},{{ item.sha256Fingerprint }}
{%-     endfor %}
{%- endfor %}
{% else %}{% if filetype_loop == 1 %}
# ISE System Certificates
| ID | Friendly Name | Serial Number Decimal Format | Issued To | Issued By | Valid From | Expiration Date | Used By | Key Size | Group Tag | Self Signed | Signature Algorithm | Portals Using The Tag | SHA 256 Fingerprint |
| -- | ------------- | ---------------------------- | --------- | --------- | ---------- | --------------- | ------- | -------- | --------- | ----------- | ------------------- | --------------------- | ------------------- |
{%- for cert in certs %}
{%-     for item in cert %}
| {{ item.id }} | {{ item.friendlyName }} | {{ item.serialNumberDecimalFormat }} | {{ item.issuedTo }} | {{ item.issuedBy }} | {{ item.validFrom }} | {{ item.expirationDate }} | {{ item.usedBy }} | {{ item.keySize }} | {{ item.groupTag }} | {{ item.selfSigned }} | {{ item.signatureAlgorithm }} | {{ item.portalsUsingTheTag | replace(","," ")}} | {{ item.sha256Fingerprint }} |
{%-     endfor %}
{%- endfor %}
{% else %}{% if filetype_loop == 2 %}
<html>
<head>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.4/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/dataTables.buttons.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.html5.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.print.min.js"></script>
    <script src="https://cdn.datatables.net/colreorder/1.5.4/js/dataTables.colReorder.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.colVis.min.js"></script>
    <script src="https://cdn.datatables.net/keytable/2.6.4/js/dataTables.keyTable.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.3.3/js/dataTables.select.min.js"></script>
    <script src="https://cdn.datatables.net/fixedheader/3.1.9/js/dataTables.fixedHeader.min.js"></script>
    <link rel="stylesheet" href="https://cdn.datatables.net/fixedheader/3.1.9/css/fixedHeader.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/select/1.3.3/css/select.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/keytable/2.6.4/css/keyTable.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.4/css/jquery.dataTables.min.css">
</head>
<body>
<h1>ISE System Certificates</h1>
<table id = "ise">
  <tr>
    <th>ID</th>
    <th>Friendly Name</th>
    <th>Serial Number Decimal Format</th>
    <th>Issued To</th>
    <th>Issued By</th>
    <th>Valid From</th>
    <th>Expiration Date</th>
    <th>Used By</th>
    <th>Key Size</th>
    <th>Group Tag</th>
    <th>Self Signed</th>
    <th>Signature Algorithm</th>
    <th>Portals Using The Tag</th>
    <th>SHA 256 Fingerprint</th>
  </tr>
{%- for cert in certs %}
{%-     for item in cert %}  
  <tr>
    <td>{{ item.id }}</td>
    <td>{{ item.friendlyName | replace (","," ")}}</td>
    <td>{{ item.serialNumberDecimalFormat }}</td>
    <td>{{ item.issuedTo }}</td>
    <td>{{ item.issuedBy }}</td>
    <td>{{ item.validFrom }}</td>
    <td>{{ item.expirationDate }}</td>
    <td>{{ item.usedBy }}</td>
    <td>{{ item.keySize }}</td>
    <td>{{ item.groupTag }}</td>
    <td>{{ item.selfSigned }}</td>
    <td>{{ item.signatureAlgorithm }}</td>
    <td>{{ item.portalsUsingTheTag }}</td>
    <td>{{ item.sha256Fingerprint }}</td>
  </tr>
{%-     endfor %}
{%- endfor %}  
</table>
<script type = "text/javascript">
  $(document).ready(function(){
    $('#ise thead tr')
    .clone(true)
    .addClass('filters')
    .appendTo('#ise thead');

    var table = $('#ise').DataTable({
        keys: true,
        dom: 'Bfrtip',
        lengthMenu: [
            [ 10, 25, 50, -1 ],
            [ '10 rows', '25 rows', '50 rows', 'Show all' ]
        ],
        buttons: [
        'pageLength','colvis','copy', 'csv', 'excel', 'pdf', 'print'
        ],
        colReorder: true,
        select: true,            
        orderCellsTop: true,
        fixedHeader: true,
        initComplete: function () {
        var api = this.api();

        // For each column
        api
            .columns()
            .eq(0)
            .each(function (colIdx) {
                // Set the header cell to contain the input element
                var cell = $('.filters th').eq(
                    $(api.column(colIdx).header()).index()
                );
                var title = $(cell).text();
                $(cell).html('<input type="text" placeholder="' + title + '" />');

                // On every keypress in this input
                $(
                    'input',
                    $('.filters th').eq($(api.column(colIdx).header()).index())
                )
                    .off('keyup change')
                    .on('keyup change', function (e) {
                        e.stopPropagation();

                        // Get the search value
                        $(this).attr('title', $(this).val());
                        var regexr = '({search})'; //$(this).parents('th').find('select').val();

                        var cursorPosition = this.selectionStart;
                        // Search the column for that value
                        api
                            .column(colIdx)
                            .search(
                                this.value != ''
                                    ? regexr.replace('{search}', '(((' + this.value + ')))')
                                    : '',
                                this.value != '',
                                this.value == ''
                            )
                            .draw();

                        $(this)
                            .focus()[0]
                            .setSelectionRange(cursorPosition, cursorPosition);
                    });
            });
    },
});
});        
</script>
</body></html>
{%- else %}
# ISE System Certificates
{%- for cert in certs %}
{%-     for item in cert %}  
## ID: {{ item.id }}
### Friendly Name: {{ item.friendlyName | replace (","," ")}}
### Serial Number Decimal Format: {{ item.serialNumberDecimalFormat }}
### Issued
#### To: {{ item.issuedTo }}
#### By: {{ item.issuedBy }}
### Dates
#### Valid From: {{ item.validFrom }}
#### Expires: {{ item.expirationDate }}
### Used By: {{ item.usedBy }}
### Key Size: {{ item.keySize }}
### Group Tag: {{ item.groupTag }}
### Self Signed: {{ item.selfSigned }}
### Signature Algorithm: {{ item.signatureAlgorithm }}
### Portals Using The Tag: {{ item.portalsUsingTheTag }}
### SHA 256 Fingerprint: {{ item.sha256Fingerprint }}
{%-     endfor %}
{%- endfor %}  
{%- endif %}{% endif %}{% endif %}